==> sui-tool-task-manager-1.1.0.tgz: package/lib/domain/task/Repositories/LocalStateTaskRepository.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { TaskRepository } from './TaskRepository.js';
export var LocalStateTaskRepository = /*#__PURE__*/function (_TaskRepository) {
  _inheritsLoose(LocalStateTaskRepository, _TaskRepository);
  function LocalStateTaskRepository(_ref) {
    var _this;
    var config = _ref.config,
      localState = _ref.localState,
      taskEntityFactory = _ref.taskEntityFactory,
      workTaskEntityFactory = _ref.workTaskEntityFactory;
    _this = _TaskRepository.call(this) || this;
    _this._config = config;
    _this._localState = localState;
    _this._taskEntityFactory = taskEntityFactory;
    _this._workTaskEntityFactory = workTaskEntityFactory;
    return _this;
  }
  var _proto = LocalStateTaskRepository.prototype;
  _proto.saveTask = function saveTask(task) {
    var updatedState = _extends({}, this._localState, {
      tasks: [].concat(this._localState.tasks)
    });
    updatedState.tasks.push(task.toJSON());
    return updatedState;
  };
  _proto.getWork = function getWork(workId) {
    var parentTask = this._localState.tasks.find(function (task) {
      return task.work.find(function (work) {
        return work.id === workId;
      }) !== undefined;
    });
    if (parentTask === undefined) return null;
    var work = parentTask.work.find(function (work) {
      return work.id === workId;
    });
    if (work === undefined) return null;
    var workEntity = this._workTaskEntityFactory(_extends({
      config: this._config
    }, work));
    return workEntity;
  };
  _proto.updateWork = function updateWork(workEntity) {
    var updatedState = _extends({}, this._localState, {
      tasks: [].concat(this._localState.tasks)
    });
    var parentTaskIndex = updatedState.tasks.findIndex(function (task) {
      return task.work.find(function (work) {
        return work.id === workEntity._id.get();
      }) !== undefined;
    });
    if (parentTaskIndex === -1) return this._localState;
    var currentWorkIndex = updatedState.tasks[parentTaskIndex].work.findIndex(function (work) {
      return work.id === workEntity._id.get();
    });
    if (currentWorkIndex === -1) return this._localState;
    updatedState.tasks[parentTaskIndex].work[currentWorkIndex] = workEntity.toJSON();
    return updatedState;
  };
  _proto._getTasksFilteredByStatus = function _getTasksFilteredByStatus(status) {
    var _this2 = this;
    var tasks = this._localState.tasks.filter(function (task) {
      return task.status === status;
    }).map(function (task) {
      return _this2._taskEntityFactory(_extends({
        config: _this2._config
      }, task));
    });
    return tasks;
  };
  _proto.getNonStartedTasks = function getNonStartedTasks() {
    return this._getTasksFilteredByStatus(this._config.get('AVAILABLE_STATUS').QUEUED);
  };
  _proto.getInProgressTasks = function getInProgressTasks() {
    return this._getTasksFilteredByStatus(this._config.get('AVAILABLE_STATUS').IN_PROGRESS);
  };
  _proto.updateTasks = function updateTasks(tasks) {
    var updatedState = _extends({}, this._localState, {
      tasks: [].concat(this._localState.tasks)
    });
    tasks.forEach(function (task) {
      var parentTaskIndex = updatedState.tasks.findIndex(function (existingTask) {
        return existingTask.id === task._id.get();
      });
      if (parentTaskIndex !== -1) {
        updatedState.tasks[parentTaskIndex] = task.toJSON();
      }
    });
    return updatedState;
  };
  return LocalStateTaskRepository;
}(TaskRepository);

==> sui-tool-task-manager-1.16.0.tgz: package/lib/domain/task/Repositories/LocalStateTaskRepository.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { TaskRepository } from './TaskRepository.js';
export var LocalStateTaskRepository = /*#__PURE__*/function (_TaskRepository) {
  _inheritsLoose(LocalStateTaskRepository, _TaskRepository);
  function LocalStateTaskRepository(_ref) {
    var _this;
    var config = _ref.config,
      localState = _ref.localState,
      taskEntityFactory = _ref.taskEntityFactory,
      workTaskEntityFactory = _ref.workTaskEntityFactory;
    _this = _TaskRepository.call(this) || this;
    _this._config = config;
    _this._localState = localState;
    _this._taskEntityFactory = taskEntityFactory;
    _this._workTaskEntityFactory = workTaskEntityFactory;
    return _this;
  }
  var _proto = LocalStateTaskRepository.prototype;
  _proto.saveTask = function saveTask(task) {
    var updatedState = _extends({}, this._localState, {
      tasks: [].concat(this._localState.tasks)
    });
    updatedState.tasks.push(task.toJSON());
    return updatedState;
  };
  _proto.getWork = function getWork(taskId, workId) {
    var parentTask = this._localState.tasks.find(function (task) {
      return task.id === taskId;
    });
    if (parentTask === undefined) return null;
    var work = parentTask.work.find(function (work) {
      return work.id === workId;
    });
    if (work === undefined) return null;
    var workEntity = this._workTaskEntityFactory(_extends({
      config: this._config
    }, work));
    return workEntity;
  };
  _proto.updateWork = function updateWork(workEntity) {
    var updatedState = _extends({}, this._localState, {
      tasks: [].concat(this._localState.tasks)
    });
    var parentTaskIndex = updatedState.tasks.findIndex(function (task) {
      return task.id === workEntity._taskId.get();
    });
    if (parentTaskIndex === -1) return this._localState;
    var currentWorkIndex = updatedState.tasks[parentTaskIndex].work.findIndex(function (work) {
      return work.id === workEntity._id.get();
    });
    if (currentWorkIndex === -1) return this._localState;
    updatedState.tasks[parentTaskIndex].work[currentWorkIndex] = workEntity.toJSON();
    return updatedState;
  };
  _proto._getTasksFilteredByStatus = function _getTasksFilteredByStatus(status) {
    var _this2 = this;
    var tasks = this._localState.tasks.filter(function (task) {
      return task.status === status;
    }).map(function (task) {
      return _this2._taskEntityFactory(_extends({
        config: _this2._config
      }, task));
    });
    return tasks;
  };
  _proto.getNonStartedTasks = function getNonStartedTasks() {
    return this._getTasksFilteredByStatus(this._config.get('AVAILABLE_STATUS').QUEUED);
  };
  _proto.getInProgressTasks = function getInProgressTasks() {
    return this._getTasksFilteredByStatus(this._config.get('AVAILABLE_STATUS').IN_PROGRESS);
  };
  _proto.updateTasks = function updateTasks(tasks) {
    var updatedState = _extends({}, this._localState, {
      tasks: [].concat(this._localState.tasks)
    });
    tasks.forEach(function (task) {
      var parentTaskIndex = updatedState.tasks.findIndex(function (existingTask) {
        return existingTask.id === task._id.get();
      });
      if (parentTaskIndex !== -1) {
        updatedState.tasks[parentTaskIndex] = task.toJSON();
      }
    });
    return updatedState;
  };
  return LocalStateTaskRepository;
}(TaskRepository);
